@@ -17,9 +17,9 @@ function (X, y, ind, tind, n, k, t., nT, w, w2, coef0 = rep(0, 3),
     ## - calc final covariances
     ## - make list of results
 
-    # mark
-    #print("uso versione 0") # done from saremsrREmod4.R
-
+    ## if w2!=w has been specified, then let w=w2
+    w <- w2
+    
     ## set names for final parms vectors
     nam.beta <- dimnames(X)[[2]]
     nam.errcomp <- c("phi", "rho")
@@ -127,7 +127,7 @@ function (X, y, ind, tind, n, k, t., nT, w, w2, coef0 = rep(0, 3),
 
     } else {
 
-        require(maxLik)
+        #require(maxLik)
 
         ## initial values are not allowed to be zero
         maxout<-function(x,a) ifelse(x>a, x, a)
